@@ -8,11 +8,13 @@
 
 import logging
 from dataclasses import dataclass, asdict
-from typing import Type, Iterable
+from enum import StrEnum, unique
+from typing import Type, Iterable, Any
 
 from http_tools import AbmServiceConnector
 from http_tools.long_requests_middleware import first
 from init_helpers import conditional_set
+from init_helpers.custom_json import Jsonable
 from init_helpers.dict_to_dataclass import dict_to_dataclass
 
 from .entity_order import entity_order_as_dict, EntityOrder
@@ -25,6 +27,12 @@ logger = logging.getLogger(__name__)
 
 
 class EntityServerConnector:
+    @unique
+    class Method(StrEnum):
+        ADD = 'add'
+        GET = 'get'
+        DELETE = 'delete'
+
     @dataclass(kw_only=True)
     class Config(AbmServiceConnector.Config):
         server_name: str
@@ -65,9 +73,7 @@ class EntityServerConnector:
         conditional_set(
             payload, order_by=[entity_order_as_dict(o) for o in to_list(order_by)] if order_by else None
         )
-        entities = await self._connector.post(
-            f'/entity/{entity_type.__entity_name__}/get', payload=payload, headers=self._construct_headers()
-        )
+        entities = await self._execute_post_request(self.Method.GET, entity_type, payload)
         return [dict_to_dataclass(entity_values, entity_type) for entity_values in entities]
 
     async def add_one(self, entity: Entity) -> int:
@@ -90,9 +96,7 @@ class EntityServerConnector:
             values_to_add.append(asdict(entity))
 
         payload = dict(values=values_to_add)
-        entity_ids = await self._connector.post(
-            f'/entity/{entity_type.__entity_name__}/add', payload=payload, headers=self._construct_headers()
-        )
+        entity_ids = await self._execute_post_request(self.Method.ADD, entity_type, payload)
         return entity_ids
 
     async def delete(self,
@@ -102,10 +106,13 @@ class EntityServerConnector:
             raise TypeError("expected entity_dataclass type")
 
         payload = dict(filter_by=[entity_condition_as_dict(f) for f in to_list(filter_by)])
-        deletion_status = await self._connector.post(
-            f'/entity/{entity_type.__entity_name__}/delete', payload=payload, headers=self._construct_headers()
-        )
+        deletion_status = await self._execute_post_request(self.Method.DELETE, entity_type, payload)
         return deletion_status
 
+    async def _execute_post_request(self, method: Method, entity_type: Type[Entity], payload: Jsonable) -> Any:
+        return await self._connector.post(
+            f'/entity/{entity_type.__entity_name__}/{method}', payload=payload, headers=self._construct_headers()
+        )
+
     def _construct_headers(self) -> dict[str, str]:
         return {'server_name': self.config.server_name}
